@@ -31,7 +31,7 @@ from secrets import token_urlsafe
 from databases import Database
 from aiohttp import ClientSession
 
-import aiob2
+import backblaze
 
 from .tables import create_tables
 from .resources import Sessions, Config
@@ -40,7 +40,7 @@ from .routes import ROUTES, ERROR_HANDLERS
 from .http_middleware import APIMiddleware
 
 
-__version__ = "0.0.7"
+__version__ = "0.0.9"
 
 
 MAP_IMAGES = {
@@ -65,6 +65,8 @@ class SQLMatches(Starlette):
                  secret_key: str = token_urlsafe(),
                  csrf_secret: str = token_urlsafe(),
                  map_images: dict = MAP_IMAGES,
+                 upload_delay: float = 0.1,
+                 max_upload_size: int = 80000000,
                  **kwargs) -> None:
         """
         SQLMatches server.
@@ -79,6 +81,10 @@ class SQLMatches(Starlette):
             Optionally pass your own url safe secret key.
         map_images: dict
             Key as actual map name, value as image name.
+        upload_delay: float
+            by default 0.1
+        max_upload_size: int
+            by default 80000000
         kwargs
             Additional parameters to pass to the Starlette instance.
         """
@@ -117,6 +123,8 @@ class SQLMatches(Starlette):
         Config.map_images = map_images
         Config.demo_pathway = b2_settings.pathway
         Config.cdn_url = b2_settings.cdn_url
+        Config.upload_delay = upload_delay
+        Config.max_upload_size = max_upload_size
 
         database_url = "://{}:{}@{}:{}/{}?charset=utf8mb4".format(
             database_settings.username,
@@ -130,12 +138,12 @@ class SQLMatches(Starlette):
             database_settings.engine + database_url
         )
 
-        self.aiob2 = aiob2.client(
+        self.b2 = backblaze.Awaiting(
             b2_settings.key_id,
             b2_settings.application_key
         )
 
-        Sessions.demo_bucket = self.aiob2.bucket(
+        Sessions.bucket = self.b2.bucket(
             b2_settings.bucket_id
         )
 
@@ -163,7 +171,7 @@ class SQLMatches(Starlette):
         """
 
         await Sessions.database.connect()
-        await self.aiob2.connect()
+        await self.b2.authorize()
         Sessions.aiohttp = ClientSession()
 
     async def _shutdown(self) -> None:
@@ -172,5 +180,5 @@ class SQLMatches(Starlette):
         """
 
         await Sessions.database.disconnect()
-        await self.aiob2.close()
+        await self.b2.close()
         await Sessions.aiohttp.close()
